from PlayerPython import * 
import CompuCellSetup
from PySteppables import *
import CompuCell
import sys

from PySteppablesExamples import MitosisSteppableBase          

class ConstraintInitializerSteppable(SteppableBasePy):
    def __init__(self,_simulator,_frequency=1):
        SteppableBasePy.__init__(self,_simulator,_frequency)
    def start(self):
        for cell in self.cellList:
            cell.targetVolume = 100.
            cell.lambdaVolume =   2.0
            cell.targetSurface=  40.
            cell.lambdaSurface=   2.0


class GrowthSteppable(SteppableBasePy):
    def __init__(self,_simulator,_frequency=1):
        SteppableBasePy.__init__(self,_simulator,_frequency)
        self.scalarCycBField = self.createScalarFieldCellLevelPy("CycB")
        
    def start(self):
        modelFile = './Simulation/BIOMD0000000195_url.xml'  
        initialConditions = {}
#        initialConditions['SPECIES_NAME1'] = species_val1
        stepSize = 0.5
        self.addSBMLToCellIds(_modelFile=modelFile, _modelName='cellcycle', _ids=[1], 
                      _stepSize=stepSize,_initialConditions=initialConditions)
        
        for cell in self.cellList:
            cell.dict['lastCycB'] = 0 # create a place to remeber cell's last CycB value
        
    def step(self,mcs):
        self.timestepSBML()
        for cell in self.cellList:
            state = self.getSBMLState(_modelName='cellcycle', _cell=cell)  
            # color the cell by the value of CycB in the SBML model
            self.scalarCycBField[cell] = float(state["CycB"])       


class MitosisSteppable(MitosisSteppableBase):
    def __init__(self,_simulator,_frequency=1):
        MitosisSteppableBase.__init__(self,_simulator, _frequency)
    
    def step(self,mcs):
        cells_to_divide=[]                
        for cell in self.cellList:
            #print "id=", cell.id, " type=", cell.type, " volume=", cell.volume
            state = self.getSBMLState(_modelName='cellcycle', _cell=cell)  
            print "           cycB",state["CycB"]
        
            #if the cell's CycB value has crossed 0.5 then divide the cell
            if float(state["CycB"]) < 0.5 and cell.dict['lastCycB'] >= 0.5:
                cells_to_divide.append(cell)
            cell.dict['lastCycB'] = float(state["CycB"])
            
        for cell in cells_to_divide:
            # divide the cells on the list
            #self.divideCellRandomOrientation(cell)
            self.divideCellAlongMinorAxis(cell)

    def updateAttributes(self):
        # cloning the paramters of the parent cell to the daughter cell, 
        # including the SBML model        
        self.cloneParent2Child()            
        
    